| auc | R Documentation |
These functions calculate the area under the curve (AUC) for cumulative density functions of a consensus matrix. The function auc operates on an indvidual consensus matrix whereas aucs operates on an entire cluscomp analysis result as described below.
auc(x) aucs(x)
x |
For The functions will not allow any missing values (NAs). |
auc(x) returns an individual AUC value.
aucs(x) returns a data.frame with the following variables.
k |
cluster number as a factor |
a |
algorithm identifier as a factor |
aucs |
the AUC value |
Dr. T. Ian Simpson ian.simpson@ed.ac.uk
Merged consensus clustering to assess and improve class discovery with microarray data. Simpson TI, Armstrong JD and Jarman AP. BMC Bioinformatics 2010, 11:590.
consmatrix-class
#load up a test cluscomp result
data('testcmr');
#look at the result structure
summary(testcmr);
#calculate an individual AUC value for a consensus matrix
ac <- auc(testcmr$e1_kmeans_k2@cm);
#calculate all of the AUC values from the \code{cluscomp} result for algorithm 'kmeans'
kmeanscmr <- testcmr[grep('kmeans',names(testcmr))];
acs <- aucs(kmeanscmr);
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.