| auc-class | R Documentation |
Objects of class 'auc' contain a data.frame which have three variables k, a and auc
as described in the aucs function description. This class simply holds the result from a call to aucs.
Objects can be created by calls of the form new("auc", ...), although they are normally generated internally by the aucs function.
Dr. T. Ian Simpson ian.simpson@ed.ac.uk
Merged consensus clustering to assess and improve class discovery with microarray data. Simpson TI, Armstrong JD and Jarman AP. BMC Bioinformatics 2010, 11:590.
Also see the aucs function.
showClass("auc")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.