| dk-class | R Documentation |
Objects of class 'dk' contain a data.frame which have three variables k, a and deltak
as described in the deltak function description. This class simply holds the result from a call to deltak.
Objects can be created by calls of the form new("dk", ...), although they are normally generated internally by the deltak function.
Dr. T. Ian Simpson ian.simpson@ed.ac.uk
Merged consensus clustering to assess and improve class discovery with microarray data. Simpson TI, Armstrong JD and Jarman AP. BMC Bioinformatics 2010, 11:590.
Also see the aucs function.
showClass("dk")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.