| dkplot | R Documentation |
This function uses the lattice function xyplot to generate an delta-K plot from a valid "dk" class object (see dk-class).
dkplot(x)
x |
a valid "dk" class object (see |
No return value, called for side effects
Dr. T. Ian Simpson ian.simpson@ed.ac.uk
Merged consensus clustering to assess and improve class discovery with microarray data. Simpson TI, Armstrong JD and Jarman AP. BMC Bioinformatics 2010, 11:590.
consmatrix-class
#load up a test cluscomp result
data('testcmr');
#look at the result structure
summary(testcmr);
#calculate all of the AUC values from the \code{cluscomp} result for algorithm 'kmeans'
kmeanscmr <- testcmr[grep('kmeans',names(testcmr))];
acs <- aucs(kmeanscmr);
#calculate all of the delta-K values
dks <- deltak(acs);
#plot the delta-K curve
dkplot(dks);
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.