| expressionPlot | R Documentation |
This function uses the lattice function xyplot to generate a profile plot of the data values grouped by cluster in a multi-panel plot. The function
takes as input the original data.frame() and a valid "consmatrix" class object (see consmatrix-class) by which to segregate the data.
expressionPlot(x,cm);
x |
the original data.frame() object used in the clustering. |
cm |
a valid |
No return value, called for side effects
Dr. T. Ian Simpson ian.simpson@ed.ac.uk
Merged consensus clustering to assess and improve class discovery with microarray data. Simpson TI, Armstrong JD and Jarman AP. BMC Bioinformatics 2010, 11:590.
consmatrix-class
#load up the data set
data(sim_profile);
#load up an example cluscomp result with this data
data('testcmr');
#plot the expression profiles
expressionPlot(sim_profile,testcmr$e1_kmeans_k4);
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.