| membBoxPlot | R Documentation |
This function uses the lattice function bwplot to generate a box and whisker plot of membership robustness from the result of a call to the memrob function.
membBoxPlot(x)
x |
the result of a call to the |
No return value, called for side effects
Dr. T. Ian Simpson ian.simpson@ed.ac.uk
Merged consensus clustering to assess and improve class discovery with microarray data. Simpson TI, Armstrong JD and Jarman AP. BMC Bioinformatics 2010, 11:590.
memroblist-class,memrob
#load up a test cluscomp result
data('testcmr');
#calculate the membershpi robustness for one of the clustering results
mr <- memrob(testcmr$e1_kmeans_k5);
#plot the bwplot
membBoxPlot(mr);
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.