| memroblist-class | R Documentation |
Objects of class 'memroblist' are created to hold the membership robustness scores for the features (e.g. genes) of a cluster.
Objects can be created by calls of the form new("memroblist", ...), although these objects are normally created internally by the memrob function.
mrl:Object of class "data.frame" - the membership robustness list itself
Dr. T. Ian Simpson ian.simpson@ed.ac.uk
Merged consensus clustering to assess and improve class discovery with microarray data. Simpson TI, Armstrong JD and Jarman AP. BMC Bioinformatics 2010, 11:590.
Also see the memrob function/
showClass("memroblist")
#load a cmr
data(testcmr);
#calculate the membership robustness for agnes, k=4
mr <- memrob(testcmr$e2_agnes_k4);
#get a membership robustness list
mrl <- mr$cluster1;
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.